==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/flywheel/backend/engine/uniform/LevelUniforms.java <==
package com.zurrtum.create.client.flywheel.backend.engine.uniform;

import com.zurrtum.create.client.flywheel.api.backend.RenderContext;
import org.joml.Vector3f;

import java.util.EnumMap;
import java.util.Map;
import net.minecraft.class_1937;
import net.minecraft.class_308;
import net.minecraft.class_5321;
import net.minecraft.class_638;
import net.minecraft.class_9848;

public final class LevelUniforms extends UniformWriter {
    private static final int SIZE = 16 * 4 + 4 * 12;
    static final UniformBuffer BUFFER = new UniformBuffer(Uniforms.LEVEL_INDEX, SIZE);
    static final Map<class_308.class_11274, float[]> CACHE = new EnumMap<>(class_308.class_11274.class);

    public static float[] LIGHT_DIRECTION;

    private LevelUniforms() {
    }

    public static void update(class_308.class_11274 type, Vector3f light0Diffusion, Vector3f light1Diffusion) {
        float[] diffusions = CACHE.computeIfAbsent(type, t -> new float[6]);
        diffusions[0] = light0Diffusion.x;
        diffusions[1] = light0Diffusion.y;
        diffusions[2] = light0Diffusion.z;
        diffusions[3] = light1Diffusion.x;
        diffusions[4] = light1Diffusion.y;
        diffusions[5] = light1Diffusion.z;
    }

    public static void set(class_308.class_11274 type) {
        LIGHT_DIRECTION = CACHE.computeIfAbsent(type, t -> new float[6]);
    }

    public static void update(RenderContext context) {
        long ptr = BUFFER.ptr();

        class_638 level = context.level();
        float partialTick = context.partialTick();

        int skyColor = level.method_23777(context.camera().method_19326(), partialTick);
        int cloudColor = level.method_23785(partialTick);
        ptr = writeVec4(ptr, class_9848.method_65101(skyColor), class_9848.method_65102(skyColor), class_9848.method_65103(skyColor), 1f);
        ptr = writeVec4(ptr, class_9848.method_65101(cloudColor), class_9848.method_65102(cloudColor), class_9848.method_65103(cloudColor), 1f);

        ptr = writeVec3(ptr, LIGHT_DIRECTION[0], LIGHT_DIRECTION[1], LIGHT_DIRECTION[2]);
        ptr = writeVec3(ptr, LIGHT_DIRECTION[3], LIGHT_DIRECTION[4], LIGHT_DIRECTION[5]);

        long dayTime = level.method_8532();
        long levelDay = dayTime / 24000L;
        float timeOfDay = (float) (dayTime - levelDay * 24000L) / 24000f;
        ptr = writeInt(ptr, (int) (levelDay % 0x7FFFFFFFL));
        ptr = writeFloat(ptr, timeOfDay);

        ptr = writeInt(ptr, level.method_8597().comp_642() ? 1 : 0);

        ptr = writeFloat(ptr, level.method_8442(partialTick));

        ptr = writeFloat(ptr, level.method_30272());
        ptr = writeInt(ptr, level.method_30273());

        ptr = writeInt(ptr, level.method_8419() ? 1 : 0);
        ptr = writeFloat(ptr, level.method_8430(partialTick));
        ptr = writeInt(ptr, level.method_8546() ? 1 : 0);
        ptr = writeFloat(ptr, level.method_8478(partialTick));

        ptr = writeFloat(ptr, level.method_23783(partialTick));

        ptr = writeInt(ptr, level.method_28103().method_29993() ? 1 : 0);

        // TODO: use defines for custom dimension ids
        int dimensionId;
        class_5321<class_1937> dimension = level.method_27983();
        if (class_1937.field_25179.equals(dimension)) {
            dimensionId = 0;
        } else if (class_1937.field_25180.equals(dimension)) {
            dimensionId = 1;
        } else if (class_1937.field_25181.equals(dimension)) {
            dimensionId = 2;
        } else {
            dimensionId = -1;
        }
        ptr = writeInt(ptr, dimensionId);

        BUFFER.markDirty();
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/flywheel/backend/engine/uniform/LevelUniforms.java <==
package com.zurrtum.create.client.flywheel.backend.engine.uniform;

import com.zurrtum.create.client.flywheel.api.backend.RenderContext;
import org.joml.Vector3f;

import java.util.EnumMap;
import java.util.Map;
import net.minecraft.class_12131;
import net.minecraft.class_12202;
import net.minecraft.class_12206;
import net.minecraft.class_1937;
import net.minecraft.class_2874;
import net.minecraft.class_308;
import net.minecraft.class_4184;
import net.minecraft.class_5321;
import net.minecraft.class_638;
import net.minecraft.class_9848;

public final class LevelUniforms extends UniformWriter {
    private static final int SIZE = 16 * 4 + 4 * 12;
    static final UniformBuffer BUFFER = new UniformBuffer(Uniforms.LEVEL_INDEX, SIZE);
    static final Map<class_308.class_11274, float[]> CACHE = new EnumMap<>(class_308.class_11274.class);

    public static float[] LIGHT_DIRECTION;

    private LevelUniforms() {
    }

    public static void update(class_308.class_11274 type, Vector3f light0Diffusion, Vector3f light1Diffusion) {
        float[] diffusions = CACHE.computeIfAbsent(type, t -> new float[6]);
        diffusions[0] = light0Diffusion.x;
        diffusions[1] = light0Diffusion.y;
        diffusions[2] = light0Diffusion.z;
        diffusions[3] = light1Diffusion.x;
        diffusions[4] = light1Diffusion.y;
        diffusions[5] = light1Diffusion.z;
    }

    public static void set(class_308.class_11274 type) {
        LIGHT_DIRECTION = CACHE.computeIfAbsent(type, t -> new float[6]);
    }

    public static void update(RenderContext context) {
        long ptr = BUFFER.ptr();

        class_638 level = context.level();
        float partialTick = context.partialTick();

        class_4184 camera = context.camera();
        class_12202 attributeProbe = camera.method_75756();
        int skyColor = attributeProbe.method_75689(class_12206.field_63746, partialTick);
        int cloudColor = camera.method_75756().method_75689(class_12206.field_64126, partialTick);
        ptr = writeVec4(ptr, class_9848.method_65101(skyColor), class_9848.method_65102(skyColor), class_9848.method_65103(skyColor), 1f);
        ptr = writeVec4(ptr, class_9848.method_65101(cloudColor), class_9848.method_65102(cloudColor), class_9848.method_65103(cloudColor), 1f);

        ptr = writeVec3(ptr, LIGHT_DIRECTION[0], LIGHT_DIRECTION[1], LIGHT_DIRECTION[2]);
        ptr = writeVec3(ptr, LIGHT_DIRECTION[3], LIGHT_DIRECTION[4], LIGHT_DIRECTION[5]);

        long dayTime = level.method_8532();
        long levelDay = dayTime / 24000L;
        float timeOfDay = (float) (dayTime - levelDay * 24000L) / 24000f;
        ptr = writeInt(ptr, (int) (levelDay % 0x7FFFFFFFL));
        ptr = writeFloat(ptr, timeOfDay);

        ptr = writeInt(ptr, level.method_8597().comp_642() ? 1 : 0);

        ptr = writeFloat(ptr, attributeProbe.method_75689(class_12206.field_64340, partialTick) * (float) (Math.PI / 180.0));

        class_12131 moonPhase = attributeProbe.method_75689(class_12206.field_64343, partialTick);
        ptr = writeFloat(ptr, class_2874.field_24752[moonPhase.method_75261()]);
        ptr = writeInt(ptr, moonPhase.method_75261());

        ptr = writeInt(ptr, level.method_8419() ? 1 : 0);
        ptr = writeFloat(ptr, level.method_8430(partialTick));
        ptr = writeInt(ptr, level.method_8546() ? 1 : 0);
        ptr = writeFloat(ptr, level.method_8478(partialTick));

        ptr = writeFloat(ptr, level.method_8594());

        ptr = writeInt(ptr, level.method_8597().comp_5221() == class_2874.class_12325.field_64381 ? 1 : 0);

        // TODO: use defines for custom dimension ids
        int dimensionId;
        class_5321<class_1937> dimension = level.method_27983();
        if (class_1937.field_25179.equals(dimension)) {
            dimensionId = 0;
        } else if (class_1937.field_25180.equals(dimension)) {
            dimensionId = 1;
        } else if (class_1937.field_25181.equals(dimension)) {
            dimensionId = 2;
        } else {
            dimensionId = -1;
        }
        ptr = writeInt(ptr, dimensionId);

        BUFFER.markDirty();
    }
}
